@@ -1,6 +1,6 @@
 package Calendar::Julian;
 
-$Calendar::Julian::VERSION   = '0.05';
+$Calendar::Julian::VERSION   = '0.06';
 $Calendar::Julian::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Calendar::Julian - Interface to Julian Calendar.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
@@ -18,7 +18,7 @@ use Data::Dumper;
 
 use Date::Julian::Simple;
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 use overload q{""} => 'as_string', fallback => 1;
 
 has year  => (is => 'rw', predicate => 1);
